# SPDX-FileCopyrightText: 2018 Brent Rubell for Adafruit Industries
# SPDX-FileCopyrightText: 2021 IAMLIUBO
#
# SPDX-License-Identifier: MIT

"""
`ttn_cn`
======================================================
The Things Network Frequency Plans - CN470
* Author(s): IAMLIUBO
"""
TTN_FREQS = {
    0: (0x79, 0x93, 0x33),  # 486.3 MHz
    1: (0x79, 0xA0, 0x00),  # 486.5 MHz
    2: (0x79, 0xAC, 0xCC),  # 486.7 MHz
    3: (0x79, 0xB9, 0x99),  # 486.9 MHz
    4: (0x79, 0xC6, 0x66),  # 487.1 MHz
    5: (0x79, 0xD3, 0x33),  # 487.3 MHz
    6: (0x79, 0xE0, 0x00),  # 487.5 MHz
    7: (0x79, 0xEC, 0xCC),
}  # 487.7 MHz
